summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--IkiWiki/Plugin/txt.pm (renamed from IkiWiki/Plugin/plaintext.pm)4
1 files changed, 2 insertions, 2 deletions
diff --git a/IkiWiki/Plugin/plaintext.pm b/IkiWiki/Plugin/txt.pm
index eaa2725b9..a4df54b55 100644
--- a/IkiWiki/Plugin/plaintext.pm
+++ b/IkiWiki/Plugin/txt.pm
@@ -1,10 +1,10 @@
#!/usr/bin/perl
# Plaintext as a wiki page type - links WikiLinks and URIs.
#
# Copyright (C) 2008 Gabriel McManus <gmcmanus@gmail.com>
# Licensed under the GNU General Public License, version 2 or later
-package IkiWiki::Plugin::plaintext;
+package IkiWiki::Plugin::txt;
use warnings;
use strict;
@@ -1,10 +1,10 @@
#!/usr/bin/perl
-# Plaintext as a wiki page type - links WikiLinks and URIs.
+# .txt as a wiki page type - links WikiLinks and URIs.
#
# Copyright (C) 2008 Gabriel McManus <gmcmanus@gmail.com>